<?php
namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class HTBS_Hours_Elementor_Widget extends Widget_Base {

   public function get_name() {
        return 'htbs_hours-addons';
    }
    
    public function get_title() {
        return esc_html__( 'HT Business Hours', 'htbs-hours' );
    }

    public function get_icon() {
        return 'htbs-hours-icon eicon-countdown';
    }
    public function get_categories() {
        return [ 'general' ];
    }

    protected function register_controls() {

        $this->start_controls_section(
            'businesshours_content',
            [
                'label' => esc_html__( 'Business Hours', 'htbs-hours' ),
            ]
        );

            $this->add_control(
                'business_hours_layout',
                [
                    'label' => esc_html__( 'Layout', 'htbs-hours' ),
                    'type' => Controls_Manager::SELECT,
                    'default' => '1',
                    'options' => [
                        '1'   => esc_html__( 'Layout One', 'htbs-hours' ),
                        '2'   => esc_html__( 'Layout Two', 'htbs-hours' ),
                        '3'   => esc_html__( 'Layout Three', 'htbs-hours' ),
                        '4'   => esc_html__( 'Layout Four', 'htbs-hours' ),
                        '5'   => esc_html__( 'Layout Five', 'htbs-hours' ),
                    ],
                    'separator'=>'after',
                ]
            );

            $repeater = new Repeater();

            $repeater->add_control(
                'business_day',
                [
                    'label'   => esc_html__( 'Day', 'htbs-hours' ),
                    'type'    => Controls_Manager::TEXT,
                    'default' => esc_html__( 'Saturday', 'htbs-hours' ),
                ]
            );

            $repeater->add_control(
                'business_time',
                [
                    'label'   => esc_html__( 'Time', 'htbs-hours' ),
                    'type'    => Controls_Manager::TEXTAREA,
                    'default' => esc_html__( '9:00 AM - 6:00 PM', 'htbs-hours' ),
                ]
            );

            $repeater->add_control(
                'highlight_this_day',
                [
                    'label'        => esc_html__( 'Hight Light this day', 'htbs-hours' ),
                    'type'         => Controls_Manager::SWITCHER,
                    'return_value' => 'yes',
                    'default'      => 'no',
                    'separator'    => 'before',
                ]
            );

            $repeater->add_control(
                'single_business_day_color',
                [
                    'label'     => esc_html__( 'Day Color', 'htbs-hours' ),
                    'type'      => Controls_Manager::COLOR,
                    'default'   => '#fa2d2d',
                    'selectors' => [
                        '{{WRAPPER}} .htbs-hours-single-hrs{{CURRENT_ITEM}}.htbs-hours-single-hrs.closed-day span.day' => 'color: {{VALUE}}',
                    ],
                    'condition' => [
                        'highlight_this_day' => 'yes',
                    ],
                    'separator' => 'before',
                ]
            );

            $repeater->add_control(
                'single_business_time_color',
                [
                    'label'     => esc_html__( 'Time Color', 'htbs-hours' ),
                    'type'      => Controls_Manager::COLOR,
                    'default'   => '#fa2d2d',
                    'selectors' => [
                        '{{WRAPPER}} .htbs-hours-single-hrs{{CURRENT_ITEM}}.htbs-hours-single-hrs.closed-day span.time' => 'color: {{VALUE}}',
                    ],
                    'condition' => [
                        'highlight_this_day' => 'yes',
                    ],
                    'separator' => 'before',
                ]
            );

            $repeater->add_control(
                'single_business_background_color',
                [
                    'label'     => esc_html__( 'Background Color', 'htbs-hours' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .htbs-hours-single-hrs{{CURRENT_ITEM}}.htbs-hours-single-hrs.closed-day' => 'background-color: {{VALUE}}',
                    ],
                    'condition' => [
                        'highlight_this_day' => 'yes',
                    ],
                    'separator' => 'before',
                ]
            );

            $this->add_control(
                'business_openday_list',
                [
                    'type'    => Controls_Manager::REPEATER,
                    'fields'  => $repeater->get_controls(),
                    'default' => [
                        [
                            'business_day' => esc_html__( 'Saturday', 'htbs-hours' ),
                            'business_time' => esc_html__( '9:00 AM to 6:00 PM','htbs-hours' ),
                        ],

                        [
                            'business_day' => esc_html__( 'Sunday', 'htbs-hours' ),
                            'business_time' => esc_html__( 'Close','htbs-hours' ),
                            'highlight_this_day' => esc_html__( 'yes','htbs-hours' ),
                        ],

                        [
                            'business_day' => esc_html__( 'Monday', 'htbs-hours' ),
                            'business_time' => esc_html__( '9:00 AM to 6:00 PM','htbs-hours' ),
                        ],

                        [
                            'business_day' => esc_html__( 'Tues Day', 'htbs-hours' ),
                            'business_time' => esc_html__( '9:00 AM to 6:00 PM','htbs-hours' ),
                        ],

                        [
                            'business_day' => esc_html__( 'Wednesday', 'htbs-hours' ),
                            'business_time' => esc_html__( '9:00 AM to 6:00 PM','htbs-hours' ),
                        ],

                        [
                            'business_day' => esc_html__( 'Thursday', 'htbs-hours' ),
                            'business_time' => esc_html__( '9:00 AM to 6:00 PM','htbs-hours' ),
                        ],

                        [
                            'business_day' => esc_html__( 'Friday', 'htbs-hours' ),
                            'business_time' => esc_html__( '9:00 AM to 6:30 PM','htbs-hours' ),
                        ]
                    ],
                    'title_field' => '{{{ business_day }}}',
                ]
            );
            
        $this->end_controls_section();


        // Style Area section
        $this->start_controls_section(
            'business_item_area_style_section',
            [
                'label' => esc_html__( 'Item Area', 'htbs-hours' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
            $this->add_group_control(
                Group_Control_Background::get_type(),
                [
                    'name' => 'business_item_area_background',
                    'label' => esc_html__( 'Background', 'htbs-hours' ),
                    'types' => [ 'classic', 'gradient' ],
                    'selector' => '{{WRAPPER}} .htbs-hours-business-hours .business-hrs-inner',
                ]
            );

            $this->add_group_control(
                Group_Control_Box_Shadow::get_type(),
                [
                    'name' => 'business_item_area_box_shadow',
                    'label' => esc_html__( 'Box Shadow', 'htbs-hours' ),
                    'selector' => '{{WRAPPER}} .htbs-hours-business-hours .business-hrs-inner',
                ]
            );

            $this->add_responsive_control(
                'business_item_area_margin',
                [
                    'label' => esc_html__( 'Margin', 'htbs-hours' ),
                    'type' => Controls_Manager::DIMENSIONS,
                    'size_units' => [ 'px', '%', 'em' ],
                    'selectors' => [
                        '{{WRAPPER}} .htbs-hours-business-hours .business-hrs-inner' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                    'separator' =>'before',
                ]
            );

            $this->add_responsive_control(
                'business_item_area_padding',
                [
                    'label' => esc_html__( 'Padding', 'htbs-hours' ),
                    'type' => Controls_Manager::DIMENSIONS,
                    'size_units' => [ 'px', '%', 'em' ],
                    'selectors' => [
                        '{{WRAPPER}} .htbs-hours-business-hours .business-hrs-inner' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                    'separator' =>'after',
                ]
            );

            $this->add_group_control(
                Group_Control_Border::get_type(),
                [
                    'name' => 'business_item_area_border',
                    'label' => esc_html__( 'Border', 'htbs-hours' ),
                    'selector' => '{{WRAPPER}} .htbs-hours-business-hours .business-hrs-inner',
                ]
            );

            $this->add_responsive_control(
                'business_item_area_radius',
                [
                    'label' => esc_html__( 'Border Radius', 'htbs-hours' ),
                    'type' => Controls_Manager::DIMENSIONS,
                    'selectors' => [
                        '{{WRAPPER}} .htbs-hours-business-hours .business-hrs-inner' => 'border-radius: {{TOP}}px {{RIGHT}}px {{BOTTOM}}px {{LEFT}}px;',
                    ],
                ]
            );

        $this->end_controls_section();

        // Style Item section
        $this->start_controls_section(
            'business_item_style_section',
            [
                'label' => esc_html__( 'Item', 'htbs-hours' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

            $this->add_responsive_control(
                'business_item_margin',
                [
                    'label' => esc_html__( 'Margin', 'htbs-hours' ),
                    'type' => Controls_Manager::DIMENSIONS,
                    'size_units' => [ 'px', '%', 'em' ],
                    'selectors' => [
                        '{{WRAPPER}} .htbs-hours-business-hours .htbs-hours-single-hrs' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                    'separator' =>'before',
                ]
            );

            $this->add_responsive_control(
                'business_item_padding',
                [
                    'label' => esc_html__( 'Padding', 'htbs-hours' ),
                    'type' => Controls_Manager::DIMENSIONS,
                    'size_units' => [ 'px', '%', 'em' ],
                    'selectors' => [
                        '{{WRAPPER}} .htbs-hours-business-hours .htbs-hours-single-hrs' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                    'separator' =>'after',
                ]
            );

            $this->add_group_control(
                Group_Control_Border::get_type(),
                [
                    'name' => 'business_item_border',
                    'label' => esc_html__( 'Border', 'htbs-hours' ),
                    'selector' => '{{WRAPPER}} .htbs-hours-business-hours .htbs-hours-single-hrs',
                ]
            );

            $this->add_responsive_control(
                'business_item_radius',
                [
                    'label' => esc_html__( 'Border Radius', 'htbs-hours' ),
                    'type' => Controls_Manager::DIMENSIONS,
                    'selectors' => [
                        '{{WRAPPER}} .htbs-hours-business-hours .htbs-hours-single-hrs' => 'border-radius: {{TOP}}px {{RIGHT}}px {{BOTTOM}}px {{LEFT}}px;',
                    ],
                ]
            );
            
        $this->end_controls_section();

        // Style Business day section
        $this->start_controls_section(
            'business_day_style_section',
            [
                'label' => esc_html__( 'Day', 'htbs-hours' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

            $this->add_control(
                'business_day_color',
                [
                    'label'     => esc_html__( 'color', 'htbs-hours' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .htbs-hours-business-hours .htbs-hours-single-hrs span.day' => 'color: {{VALUE}};',
                    ],
                ]
            );
            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'business_day_typography',
                    'selector' => '{{WRAPPER}} .htbs-hours-business-hours .htbs-hours-single-hrs span.day',
                ]
            );

            $this->add_group_control(
                Group_Control_Background::get_type(),
                [
                    'name' => 'business_day_background',
                    'label' => esc_html__( 'Background', 'htbs-hours' ),
                    'types' => [ 'classic', 'gradient' ],
                    'selector' => '{{WRAPPER}} .htbs-hours-business-hours .htbs-hours-single-hrs span.day',
                ]
            );
            
        $this->end_controls_section();

        // Style Business Time section
        $this->start_controls_section(
            'business_time_style_section',
            [
                'label' => esc_html__( 'Time', 'htbs-hours' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

            $this->add_control(
                'business_time_color',
                [
                    'label'     => esc_html__( 'color', 'htbs-hours' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .htbs-hours-business-hours .htbs-hours-single-hrs span.time' => 'color: {{VALUE}};',
                    ],
                ]
            );
            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'business_time_typography',
                    'selector' => '{{WRAPPER}} .htbs-hours-business-hours .htbs-hours-single-hrs span.time',
                ]
            );

            $this->add_group_control(
                Group_Control_Background::get_type(),
                [
                    'name' => 'business_time_background',
                    'label' => esc_html__( 'Background', 'htbs-hours' ),
                    'types' => [ 'classic', 'gradient' ],
                    'selector' => '{{WRAPPER}} .htbs-hours-business-hours .htbs-hours-single-hrs span.time',
                ]
            );
            
        $this->end_controls_section();

    }

    protected function render( $instance = [] ) {

        $settings   = $this->get_settings_for_display();

        $this->add_render_attribute( 'htbs-hours_business_hours', 'class', 'htbs-hours-business-hours htbs-hours-business-horurs-'.$settings['business_hours_layout'] );
       
        ?>

        <div <?php echo $this->get_render_attribute_string( 'htbs-hours_business_hours' ); ?>>
            <div class="business-hrs-inner">
                <?php
                    foreach ( $settings['business_openday_list'] as $item ):
                ?>

                    <div class="htbs-hours-single-hrs elementor-repeater-item-<?php echo $item['_id']; ?> <?php if( $item['highlight_this_day'] == 'yes' ){ echo esc_attr( 'closed-day','htbs-hours'); }?>">
                        <?php
                            if( !empty( $item['business_day'] ) ){
                                echo '<span class="day">'.esc_html__( $item['business_day'],'htbs-hours' ).'</span>';
                            }
                            if( !empty( $item['business_time'] ) ){
                                echo '<span class="time">'.esc_html__( $item['business_time'],'htbs-hours' ).'</span>';
                            }
                        ?>
                    </div>

                <?php endforeach; ?>
            </div>
        </div>

        <?php

    }

}
htbs_hours_widget_register_manager( new HTBS_Hours_Elementor_Widget() );
